@@ -1,6 +1,7 @@
 package Digest::SHA;
 
-use 5.008;
+#use 5.008;
+use base 'Digest::base';
 use strict;
 use warnings;
 
@@ -66,7 +67,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} }, @{ $EXPORT_TAGS{'legacy'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '4.0.0';
+our $VERSION = '4.0.2';
 
 require XSLoader;
 XSLoader::load('Digest::SHA', $VERSION);
@@ -400,14 +401,9 @@ sub add_bits {
 	return($self);
 }
 
+# tweaked by jcd
 sub addfile {
-	my $self = shift;
-	my $fh = shift;
-	my $buf;
-	while (read($fh, $buf, 1<<12)) {
-		shawrite($buf, $self->{STATE});
-	}
-	return($self);
+	return Digest::base::addfile(@_);
 }
 
 sub dump {
