@@ -5,8 +5,8 @@
  *
  * Copyright (C) 2003 Mark Shelor, All Rights Reserved
  *
- * Version: 2.4
- * Sat Nov 22 17:10:22 MST 2003
+ * Version: 4.0.0
+ * Sat Nov 29 23:18:45 MST 2003
  *
  */
 
@@ -17,6 +17,7 @@
 #include "sha.h"
 #include "sha64bit.h"
 #include "endian.h"
+#include "fmt.h"
 
 #define SHR(x, n)	( (x) >> (n) )
 #define ROTR(x, n)	( ( (x) >> (n) ) | ( (x) << (32 - (n)) ) )
@@ -616,8 +617,10 @@ char *file;
 int shaclose(s)
 SHA *s;
 {
-	memset(s, 0, sizeof(SHA));
-	free(s);
+	if (s != NULL) {
+		memset(s, 0, sizeof(SHA));
+		free(s);
+	}
 	return(0);
 }
 
